#
# spec file for package osmo-hlr
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2016-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-hlr
Version:        1.4.0
Release:        2.5
Summary:        Osmocom Home Location Register for GSUP protocol towards OsmoSGSN and OsmoCSCN
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Productivity/Telephony/Servers
URL:            https://projects.osmocom.org/projects/osmo-hlr
Source:         %{name}-%{version}.tar.xz
Patch0:         harden_osmo-hlr.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  python3
BuildRequires:  sqlite3
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libosmoabis) >= 1.1.0
BuildRequires:  pkgconfig(libosmocore) >= 1.5.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.5.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.5.0
BuildRequires:  pkgconfig(libosmovty) >= 1.5.0
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(talloc) >= 2.0.1
# only needed for populate_hlr_db.pl
Requires:       libdbi-drivers-dbd-sqlite3

%description
The GSUP HLR is a stand-alone HLR (Home Location Register) for SIM
and USIM based subscribers which exposes the GSUP protocol towards
its users. OsmoSGSN supports this protocol.

osmo-gsup-hlr is still very simplistic. It is a single-threaded
architecture and uses only sqlite3 tables as back-end.  It is suitable
for installations of the scale that OsmoNITB was able to handle.  It
also lacks various features like fine-grained control of subscribed
services (like supplementary services).

%package -n libosmo-gsup-client0
Summary:        Osmocom GSUP (General Subscriber Update Protocol) client library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-gsup-client0
This is a shared library that can be used to implement client programs for
the GSUP protocol. The typical GSUP server is OsmoHLR, with OsmoMSC, OsmoSGSN
and External USSD Entities (EUSEs) using this library to implement clients.

%package -n libosmo-gsup-client-devel
Summary:        Development files for the Osmocom GSUP client library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-gsup-client0 = %{version}

%description -n libosmo-gsup-client-devel
This is a shared library that can be used to implement client programs for
the GSUP protocol. The typical GSUP server is OsmoHLR, with OsmoMSC, OsmoSGSN
and External USSD Entities (EUSEs) using this library to implement clients.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-gsup-client.

%package -n libosmo-mslookup0
Summary:        Osmocom MS lookup library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmo-mslookup0
This shared library contains routines for looking up mobile subscribers.

%package -n libosmo-mslookup-devel
Summary:        Development files for the Osmocom MS lookup library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmo-mslookup0 = %{version}

%description -n libosmo-mslookup-devel
This shared library contains routines for looking up mobile subscribers.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmo-mslookup.

%package -n osmo-mslookup-client
Summary:        Standalone program using libosmo-mslookup
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++

%description -n osmo-mslookup-client
Standalone program using libosmo-mslookup to easily integrate with programs
that want to connect services (SIP, SMS,...) to the current location of a
subscriber.

%prep
%autosetup -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
  --docdir="%{_docdir}/%{name}" \
  --with-systemdsystemunitdir=%{_unitdir} \
  --enable-shared \
  --disable-static
make V=1 %{?_smp_mflags}

%install
%make_install
install -d "%{buildroot}/%{_localstatedir}/lib/osmocom"
find %{buildroot} -type f -name "*.la" -delete -print
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-hlr

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%post   -n libosmo-gsup-client0 -p /sbin/ldconfig
%postun -n libosmo-gsup-client0 -p /sbin/ldconfig
%post   -n libosmo-mslookup0 -p /sbin/ldconfig
%postun -n libosmo-mslookup0 -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/examples
%{_docdir}/%{name}/examples/osmo-hlr.cfg
%{_docdir}/%{name}/examples/osmo-hlr-dgsm.cfg
%dir %{_docdir}/%{name}/sql
%{_docdir}/%{name}/sql/hlr.sql
%{_docdir}/%{name}/sql//hlr_data.sql
%dir %{_sysconfdir}/osmocom
%dir %{_localstatedir}/lib/osmocom
%{_bindir}/osmo-hlr
%{_bindir}/osmo-hlr-db-tool
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-hlr.cfg
%{_unitdir}/osmo-hlr.service
%{_sbindir}/rcosmo-hlr
%dir %{_datadir}/osmocom
%{_datadir}/osmocom/osmo-hlr-post-upgrade.sh

%files -n libosmo-gsup-client0
%{_libdir}/libosmo-gsup-client.so.0*

%files -n libosmo-gsup-client-devel
%{_bindir}/osmo-euse-demo
%dir %{_includedir}/osmocom
%dir %{_includedir}/osmocom/gsupclient
%{_includedir}/osmocom/gsupclient/*.h
%{_libdir}/libosmo-gsup-client.so
%{_libdir}/pkgconfig/libosmo-gsup-client.pc

%files -n libosmo-mslookup0
%{_libdir}/libosmo-mslookup.so.0*

%files -n libosmo-mslookup-devel
%dir %{_includedir}/osmocom
%dir %{_includedir}/osmocom/mslookup
%{_includedir}/osmocom/mslookup/*.h
%{_libdir}/libosmo-mslookup.so
%{_libdir}/pkgconfig/libosmo-mslookup.pc

%files -n osmo-mslookup-client
%{_bindir}/osmo-mslookup-client

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.4.0
  * https://git.osmocom.org/osmo-hlr/plain/debian/changelog?h=1.4.0
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-hlr.service.patch
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.2.0
  * AUC: Add support for setting the AMF separation bit to '1' for EUTRAN
  * db v4: add column last_lu_seen_ps
  * fix upgrade test in presence of ~/.sqliterc
  * add --db-check option
- Update to new upstream release 1.1.0
  * db_auc.c: verify hex key sizes read from DB
  * VTY: add subscriber update network-access-mode
  * Create subscribers on demand
  * Enable statsd support
  * Optionally store IMEI in subscriber table
* Wed Jan 30 2019 mardnh@gmx.de
- Update to new upstream release 1.0.0
  * Add GSUP message router
  * Add concept of Internal (IUSE) and external (EUSE) USSD handlers
  * Implement handling of USSD received from OsmoMSC via GSUP
  * Introduce shared libosmo-gsup-client library for client programs
    connecting to OsmoHLR (like OsmoMSC, OsmoSGSN).
  * Full changelogs since 0.1.0:
    http://git.osmocom.org/osmo-hlr/plain/debian/changelog?h=1.0.0
    http://git.osmocom.org/osmo-hlr/plain/debian/changelog?h=0.2.1
    http://git.osmocom.org/osmo-hlr/plain/debian/changelog?h=0.2.0
- Remove patches:
  * 0001-doc-install-example-.cfg-files-to-docdir-examples.patch
  * 0001-fix-build-db_test-missing-LIBOSMOABIS_CFLAGS-and-_LI.patch
  * osmo-hlr-fix-docpath.patch
* Sat Mar 17 2018 mardnh@gmx.de
- Run test during build
- Package examples
- Package systemd service file
- Add patch:
  * 0001-fix-build-db_test-missing-LIBOSMOABIS_CFLAGS-and-_LI.patch
  * 0001-doc-install-example-.cfg-files-to-docdir-examples.patch
- Minor specfile cleanup
* Mon Jan  1 2018 jengelh@inai.de
- Update description and versionify BuildRequires.
- Install service file.
* Wed Dec 27 2017 mardnh@gmx.de
- Update to new upstream release 0.1.0
  * No changelog was provided
- Add patch:
  * osmo-hlr-fix-docpath.patch
* Sat Mar  4 2017 mardnh@gmx.de
- Update to version 0.0.1.git1487730330.4436dec:
  * Move GSUP msg init into separate function
  * Use strings for GSUP message type
  * Move lu_operation into separate file
  * db: move duplicated code into helper functions
  * Fix compiler's warning about printf security
  * Add routines to update nam_ps
  * auc_3g_test: add AUTS resync test
  * auc_gen_vectors(): ensure sane arguments, test
  * auc_3g_test: allow to inc fake rand bytes upon rand request
  * auc_3g_test: add AUTS test with N vectors, to show bug
  * cosmetic: refactor auc_compute_vectors(), add debug log
  * auc_compute_vectors(): fix AUTS resync for multiple vectors
  * cosmetic: auc_3g_test: improve test debugging tools
  * cosmetic: rename auc_3g_test.c to auc_test.c
* Wed Feb 15 2017 mardnh@gmx.de
- Update to version 0.0.1.git1486997618.f8c7b6f:
  * debug log: log computed vector kinds
  * log: move a log from info to debug level
  * hlr.sql: typo in comment
  * auc.c: typo in comment
  * main: add and use root talloc ctx
  * main: add option parsing with db file and default options
  * main: add VTY and '-c config-file' option
  * sql: fix 3g_auc's column K data type
  * cosmetic: sql: indicate VARCHAR size of key columns as 32
  * sql: auc_3g: set sqn NOT NULL DEFAULT 0
  * comment: sql: describe auc_2g and auc_3g columns
  * Add test suite skeleton with empty test (auc_3g_test)
  * tests: auc_3g_test: implement vector generation test
  * auth: verify test sets from 3GPP TS 55.205
  * sql: add unique constraints to IMSI and MSISDN
  * UMTS AKA resync: fix argument ordering
  * Log error cause as a string
* Sun Dec 25 2016 mardnh@gmx.de
- Update to version 0.0.1.git1482328813.627de84:
  * fix DLGSUP logging cat after change in libosmocore
  * build: recoin db_test as non-installable program
  * build: actually make sqlite mandatory
  * bump required libosmocore version to 0.9.5
  * Add gerrit settings
  * Add hardcoded APN
  * gsup: send subscriber MSISDN
* Sun Dec 11 2016 mardnh@gmx.de
- Update to version 0.0.1.git1481415765.ec1b959:
  * build with autoconf/automake, add jenkins.sh script
  * fix build on FreeBSD: eliminate implicitly declared functions
  * fix various compiler warnings
* Fri Nov 11 2016 mardnh@gmx.de
- Update to version 0.0.0.git1478855826.7f8c301:
  * State number of auth vectors in SAI response
  * AUC: use osmo_hexparse() when reading key material from db
  * some more comment / todo updates
  * implement PURGE-MS from VLR/SGSN to HLR
  * LU: correctly determine and use is_ps
  * LU: remote oudated FIXME comments
  * fix PURGE_MS sqlite3 access
  * fix authentication re-sync (pass RAND+AUTS along)
  * Fix build on Ubuntu
  * add COPYING file with AGPLv3 license text
* Fri Nov 11 2016 mardnh@gmx.de
- initial package
